@@ -4,7 +4,7 @@ from slai.modules.runtime import detect_runtime, detect_credentials
 from slai.exceptions import NoCredentialsFound
 from slai_cli import log
 from slai_cli.create import project_generator
-from slai_cli.exceptions import ProjectExistsException
+from slai_cli.exceptions import ProjectExistsException, InvalidApiKey
 
 
 @click.command()
@@ -29,5 +29,8 @@ def create(name, profile):
     except ProjectExistsException:
         log.warn(f"Project '{name}' already exists.")
         return
+    except InvalidApiKey:
+        log.warn("Invalid credentials.")
+        return
 
     pg.create_new_project()
