@@ -2,6 +2,7 @@ import os
 import click
 import git
 import yaml
+import shutil
 
 from jinja2 import Template
 from pathlib import Path
@@ -38,11 +39,10 @@ class ProjectGenerator:
         click.clear()
         log.action(f"Creating a new project with name: {self.project_name}")
 
-        try:
-            self.project_variables = self._generate_project_variables(self.project_name)
-        except (ProjectExistsException, InvalidPathException):
+        slai_directory_present = Path(".slai").is_dir()
+        if slai_directory_present and Path(".slai/config.yml").exists():
             log.warn(
-                f"A project or directory already exists with name '{self.project_name}', aborting."
+                "You cannot create nested slai projects, try again in another directory."  # noqa
             )
             return
 
@@ -53,8 +53,21 @@ class ProjectGenerator:
             log.warn(f"Invalid project name: {e}\n")
             return
 
-        # clone template repository
-        self._clone_template_repo(local_path=local_path)
+        try:
+            # clone template repository
+            self._clone_template_repo(local_path=local_path)
+        except (RuntimeError):
+            return
+
+        try:
+            self.project_variables = self._generate_project_variables(self.project_name)
+        except (ProjectExistsException, InvalidPathException):
+            log.warn(
+                f"A project or directory already exists with name '{self.project_name}', aborting."
+            )
+            project_path = Path(local_path)
+            shutil.rmtree(project_path)
+            return
 
         # store profile in project credentials file
         self._store_local_credentials()
@@ -158,7 +171,7 @@ class ProjectGenerator:
                 break
 
         if not cloned:
-            log.warn("Unable to clone template repository")
+            log.warn("Unable to clone template repository.")
             raise RuntimeError("unable_to_clone_template_repo")
 
         return local_path
