@@ -34,7 +34,7 @@ def _write_template_file(*, populated_templates, path, filename):
 
 def _populate_template_files(model):
     populated_templates = {}
-    template_files = ["notebook.ipynb", "handler.py"]
+    template_files = ["notebook.ipynb", "handler.py", "test_event.json"]
 
     pwd = Path(__file__).parent
 
@@ -73,6 +73,12 @@ def _populate_template_files(model):
         filename="handler.py",
     )
 
+    _write_template_file(
+        populated_templates=populated_templates,
+        path=f"{cwd}/handlers/{model['name']}",
+        filename="test_event.json",
+    )
+
 
 def _validate_model_name(name):
     raise NotImplementedError
