@@ -63,9 +63,15 @@ def store_credentials(*, profile_name, client_id, client_secret, runtime):
 
     # save new profile
     if runtime == ValidRuntimes.Local:
+        if credentials.get("default") is None:
+            credentials["default"] = new_profile
+
         credentials[profile_name] = new_profile
     elif runtime == ValidRuntimes.Project:
         credentials = new_profile
 
+    noalias_dumper = yaml.dumper.SafeDumper
+    noalias_dumper.ignore_aliases = lambda self, data: True
+
     with open(f"{credentials_path}/credentials.yml", "w") as f_out:
-        yaml.dump(credentials, f_out, default_flow_style=False)
+        yaml.dump(credentials, f_out, default_flow_style=False, Dumper=noalias_dumper)
